@@ -132,9 +132,7 @@ class ImportExportTest(unittest.TestCase):
 
 class ExpandTest(unittest.TestCase):
 
-    '''
-    assumes the configuration has been imported into a python dict correctly.
-    '''
+    """Assume configuration has been imported into a python dict correctly."""
 
     before_config = {
         'session_name': 'sampleconfig',
@@ -154,23 +152,46 @@ class ExpandTest(unittest.TestCase):
             {
                 'window_name': 'logging',
                 'panes': [
-                    {'shell_command': ['tail -F /var/log/syslog'],
-                     }
+                    {
+                        'shell_command': ['tail -F /var/log/syslog'],
+                    }
                 ]
             },
             {
                 'start_directory': '/var/log',
                 'options': {'automatic_rename': True, },
                 'panes': [
-                    {'shell_command': 'htop'},
+                    {
+                        'shell_command': 'htop'
+                    },
                     'vim',
                 ]
             },
+            {
+                'start_directory': './',
+                'panes': [
+                    'pwd'
+                ]
+            },
+            {
+                'start_directory': './asdf/',
+                'panes': [
+                    'pwd'
+                ]
+            },
+            {
+                'start_directory': '../',
+                'panes': [
+                    'pwd'
+                ]
+            },
+
             {
                 'panes': [
                     'top'
                 ]
-            }]
+            }
+        ]
     }
 
     after_config = {
@@ -192,8 +213,9 @@ class ExpandTest(unittest.TestCase):
             {
                 'window_name': 'logging',
                 'panes': [
-                    {'shell_command': ['tail -F /var/log/syslog'],
-                     }
+                    {
+                        'shell_command': ['tail -F /var/log/syslog'],
+                    }
                 ]
             },
             {
@@ -204,6 +226,25 @@ class ExpandTest(unittest.TestCase):
                     {'shell_command': ['vim']}
                 ]
             },
+            {
+                'start_directory': os.path.abspath('./'),
+                'panes': [
+                    {'shell_command': ['pwd']}
+                ]
+            },
+            {
+                'start_directory': os.path.abspath('./asdf/'),
+                'panes': [
+                    {'shell_command': ['pwd']}
+                ]
+            },
+            {
+                'start_directory': os.path.abspath('../'),
+                'panes': [
+                    {'shell_command': ['pwd']}
+                ]
+            },
+
             {
                 'panes': [
                     {'shell_command': ['top']}
@@ -213,9 +254,7 @@ class ExpandTest(unittest.TestCase):
     }
 
     def test_config(self):
-        '''
-        expands shell commands from string to list
-        '''
+        """Expand shell commands from string to list."""
         self.maxDiff = None
         test_config = config.expand(self.before_config)
         self.assertDictEqual(test_config, self.after_config)
@@ -223,8 +262,7 @@ class ExpandTest(unittest.TestCase):
 
 class InlineTest(unittest.TestCase):
 
-    '''tests for :meth:`config.inline()`.
-    '''
+    """Tests for :meth:`config.inline()`."""
 
     before_config = {
         'session_name': 'sampleconfig',
@@ -267,8 +305,10 @@ class InlineTest(unittest.TestCase):
                 'window_name': 'editor',
                 'panes': [
                     {
-                        'start_directory': '~', 'shell_command': 'vim',
-                    },  {
+                        'start_directory': '~',
+                        'shell_command': 'vim',
+                    },
+                    {
                         'shell_command': 'cowsay "hey"'
                     },
                 ],
@@ -277,35 +317,35 @@ class InlineTest(unittest.TestCase):
             {
                 'window_name': 'logging',
                 'panes': [
-                    {'shell_command': 'tail -F /var/log/syslog',
-                     'start_directory': '/var/log'}
+                    {
+                        'shell_command': 'tail -F /var/log/syslog',
+                        'start_directory': '/var/log'
+                    }
                 ]
             },
             {
-                'options': {'automatic_rename': True, },
+                'options': {
+                    'automatic_rename': True,
+                },
                 'panes': [
-                    {'shell_command': 'htop'}
+                    {
+                        'shell_command': 'htop'
+                    }
                 ]
             }
         ]
     }
 
     def test_config(self):
-        '''
-        config.inline() inlines shell commands from list to string where applicable
-        '''
+        """:meth:`config.inline()` shell commands list to string where applicable."""
+
         self.maxDiff = None
         test_config = config.inline(self.before_config)
         self.assertDictEqual(test_config, self.after_config)
 
 
 class InheritanceTest(unittest.TestCase):
-
-    '''
-    test config inheritance for the nested 'start_command'
-
-    format for tests will be
-    '''
+    """Test config inheritance for the nested 'start_command'."""
 
     config_before = {
         'session_name': 'sampleconfig',
@@ -316,8 +356,10 @@ class InheritanceTest(unittest.TestCase):
                 'start_directory': '~',
                 'panes': [
                     {
-                        'start_directory': '~', 'shell_command': ['vim'],
-                    },  {
+                        'start_directory': '~',
+                        'shell_command': ['vim'],
+                    },
+                    {
                         'shell_command': ['cowsay "hey"']
                     },
                 ],
@@ -364,8 +406,10 @@ class InheritanceTest(unittest.TestCase):
             {
                 'window_name': 'logging',
                 'panes': [
-                    {'shell_command': ['tail -F /var/log/syslog'],
-                        'start_directory':'/var/log'}
+                    {
+                        'shell_command': ['tail -F /var/log/syslog'],
+                        'start_directory':'/var/log'
+                    }
                 ]
             },
             {
