@@ -13,7 +13,6 @@ import logging
 logger = logging.getLogger(__name__)
 
 
-@unittest.skip('test')
 class TmuxObjectTest(TmuxTestCase):
 
     ''' test the :class:`TmuxRelationalObject` base class object.
@@ -25,7 +24,6 @@ class TmuxObjectTest(TmuxTestCase):
         # server.findWhere
         for session in t.sessions:
             session_id = session.get('session_id')
-            logger.error(session_id)
 
             self.assertEqual(t.findWhere({'session_id': session_id}), session)
             self.assertIsInstance(t.findWhere({
@@ -35,10 +33,12 @@ class TmuxObjectTest(TmuxTestCase):
             for window in session.windows:
                 window_id = window.get('window_id')
 
-                self.assertEqual(session.findWhere(
-                    {'window_id': window_id}), window)
-                self.assertIsInstance(session.findWhere(
-                    {'window_id': window_id}), Window)
+                self.assertEqual(
+                    session.findWhere({'window_id': window_id}), window
+                )
+                self.assertIsInstance(
+                    session.findWhere({'window_id': window_id}), Window
+                )
 
                 # window.findWhere
                 for pane in window.panes:
@@ -53,7 +53,7 @@ class TmuxObjectTest(TmuxTestCase):
         '''.findWhere returns objects with multiple attributes
         '''
 
-        for session in t._sessions:
+        for session in t.sessions:
             session_id = session.get('session_id')
             session_name = session.get('session_name')
             find_where = t.findWhere({
@@ -96,7 +96,7 @@ class TmuxObjectTest(TmuxTestCase):
         window = self.session.attached_window()
         window.split_window()  # create second pane
 
-        for session in t._sessions:
+        for session in t.sessions:
             session_id = session.get('session_id')
             session_name = session.get('session_name')
             where = t.where({
@@ -146,7 +146,7 @@ class TmuxObjectTest(TmuxTestCase):
 
         window.split_window()  # create second pane
 
-        for session in t._sessions:
+        for session in t.sessions:
             session_id = session.get('session_id')
             session_name = session.get('session_name')
             get_by_id = t.getById(session_id)
@@ -184,51 +184,5 @@ class TmuxObjectTest(TmuxTestCase):
                         '%' + str(random.randint(50000, 90000))
                     ))
 
-
-class ReferenceTestCase(TmuxTestCase):
-
-    @unittest.skip('not doing yet, complete unit tests first')
-    def test_mutability(self):
-        # window = self.session.attached_window()
-
-        # window.split_window()  # create second pane
-
-        for session in t._sessions:
-            session_id = session.get('session_id')
-            session_name = session.get('session_name')
-            get_by_id = t.getById(session_id)
-
-            for x in range(random.randint(1, 6)):
-                window = session.new_window()
-
-            for window in session.windows:
-                for y in range(random.randint(1, 3)):
-                    try:
-                        pane = window.split_window()
-                    except Exception as e:
-                        logger.debug(e)
-                        pass
-
-            # session.getById
-            last_window = None
-            for window in session.windows:
-                window_id = window.get('window_id')
-                window_index = window.get('window_index')
-
-                if last_window:
-                    self.assertEqual(last_window.session, window.session)
-                    self.assertEqual(id(
-                        last_window.session), id(window.session))
-                    self.assertNotEqual(last_window, window)
-                    self.assertNotEqual(id(last_window), id(window))
-                last_window = window
-
-                # window.getById
-                for pane in window.panes:
-                    pane_id = pane.get('pane_id')
-                    pane_tty = pane.get('pane_tty')
-
-                    get_by_id = window.getById(pane_id)
-
 if __name__ == '__main__':
     unittest.main()
