@@ -1,12 +1,14 @@
 # -*- coding: utf8 -*-
-"""
-    tmuxp.builder
-    ~~~~~~~~~~~~~
+"""Create a tmux workspace from a configuration :py:obj:`dict`.
 
-    tmuxp helps you manage tmux workspaces.
+tmuxp.workspacebuilder
+~~~~~~~~~~~~~~~~~~~~~~
+
+tmuxp helps you manage tmux workspaces.
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
 
-    :copyright: Copyright 2013 Tony Narlock.
-    :license: BSD, see LICENSE for details
 """
 
 from __future__ import absolute_import, division, print_function, with_statement
